# CLI options

| CLI option | arguments for `pipster.install() |
| ---------- | ---------- |
| `--abi <abi>` | `abi="<abi>"` |
| `--abi <abi1> --abi <abi2>` | `abi=["<abi1>", "<abi2>"]` |
| `--break-system-packages` | `break_system_packages=True` |
| `-c <file>` | `c="<file>"` |
| `-c <file1> -c <file2>` | `c=["<file1>", "<file2>"]` |
| `--cache-dir <dir>` | `cache_dir="<dir>"` |
| `--cert <path>` | `cert="<path>"` |
| `--check-build-dependencies` | `check_build_dependencies=True` |
| `--client-cert <path>` | `client_cert="<path>"` |
| `--compile` | `compile=True` |
| `--config-settings <settings>` | `config_settings="<settings>"` |
| `--config-settings <settings1> --config-settings <settings2>` | `config_settings=["<settings1>", "<settings2>"]` |
| `--constraint <file>` | `constraint="<file>"` |
| `--constraint <file1> --constraint <file2>` | `constraint=["<file1>", "<file2>"]` |
| `--debug` | `debug=True` |
| `--disable-pip-version-check` | `disable_pip_version_check=True` |
| `--dry-run` | `dry_run=True` |
| `-e <path/url>` | `e="<path/url>"` |
| `--editable <path/url>` | `editable="<path/url>"` |
| `--exists-action <action>` | `exists_action="<action>"` |
| `--extra-index-url <url>` | `extra_index_url="<url>"` |
| `-f <url>` | `f="<url>"` |
| `--find-links <url>` | `find_links="<url>"` |
| `--force-reinstall` | `force_reinstall=True` |
| `--global-option <options>` | `global_option="<options>"` |
| `-h` | `h=True` |
| `--help` | `help=True` |
| `-I` | `I=True` |
| `-i <url>` | `i="<url>"` |
| `--ignore-installed` | `ignore_installed=True` |
| `--ignore-requires-python` | `ignore_requires_python=True` |
| `--implementation <implementation>` | `implementation="<implementation>"` |
| `--index-url <url>` | `index_url="<url>"` |
| `--install-option <options>` | `install_option="<options>"` |
| `--isolated` | `isolated=True` |
| `--log <path>` | `log="<path>"` |
| `--no-binary <format_control>` | `no_binary="<format_control>"` |
| `--no-binary <format_control1> --no-binary <format_control2>` | `no_binary=["<format_control1>", "<format_control2>"]` |
| `--no-build-isolation` | `build_isolation=False` |
| `--no-cache-dir` | `cache_dir=False` |
| `--no-clean` | `clean=False` |
| `--no-color` | `color=False` |
| `--no-compile` | `compile=False` |
| `--no-deps` | `deps=False` |
| `--no-index` | `index=False` |
| `--no-input` | `input=False` |
| `--no-python-version-warning` | `python_version_warning=False` |
| `--no-warn-conflicts` | `warn_conflicts=False` |
| `--no-warn-script-location` | `warn_script_location=False` |
| `--only-binary <format_control>` | `only_binary="<format_control>"` |
| `--only-binary <format_control1> --only-binary <format_control2>` | `only_binary=["<format_control1>", "<format_control2>"]` |
| `--platform <platform>` | `platform="<platform>"` |
| `--platform <platform1> --platform <platform2>` | `platform=["<platform1>", "<platform2>"]` |
| `--pre` | `pre=True` |
| `--prefer-binary` | `prefer_binary=True` |
| `--prefix <dir>` | `prefix="<dir>"` |
| `--progress-bar <progress_bar>` | `progress_bar="<progress_bar>"` |
| `--proxy <proxy>` | `proxy="<proxy>"` |
| `--python <python>` | `python="<python>"` |
| `--python-version <python_version>` | `python_version="<python_version>"` |
| `-q` | `q=True` |
| `-q` | `q=1` |
| `-qq` | `q=2` |
| `-qqq` | `q=3` |
| `--quiet` | `quiet=True` |
| `-r <file>` | `r="<file>"` |
| `-r <file1> -r <file2>` | `r=["<file1>", "<file2>"]` |
| `--report <file>` | `report="<file>"` |
| `--require-hashes` | `require_hashes=True` |
| `--require-virtualenv` | `require_virtualenv=True` |
| `--requirement <file>` | `requirement="<file>"` |
| `--requirement <file1> --requirement <file2>` | `requirement=["<file1>", "<file2>"]` |
| `--retries <retries>` | `retries="<retries>"` |
| `--root <dir>` | `root="<dir>"` |
| `--root-user-action <root_user_action>` | `root_user_action="<root_user_action>"` |
| `--src <dir>` | `src="<dir>"` |
| `-t <dir>` | `t="<dir>"` |
| `--target <dir>` | `target="<dir>"` |
| `--timeout <sec>` | `timeout="<sec>"` |
| `--trusted-host <hostname>` | `trusted_host="<hostname>"` |
| `-U` | `U=True` |
| `--upgrade` | `upgrade=True` |
| `--upgrade-strategy <upgrade_strategy>` | `upgrade_strategy="<upgrade_strategy>"` |
| `--use-deprecated <feature>` | `use_deprecated="<feature>"` |
| `--use-feature <feature>` | `use_feature="<feature>"` |
| `--use-pep517` | `use_pep517=True` |
| `--user` | `user=True` |
| `-V` | `V=True` |
| `-v` | `v=True` |
| `-v` | `v=1` |
| `-vv` | `v=2` |
| `-vvv` | `v=3` |
| `--verbose` | `verbose=True` |
| `--version` | `version=True` |
